// init_3.sce
// Initialization of regression model estimation
// - model y = c1.x1 + c2.x2 + c3.x3 + k + e
// - x = m + sd.v (v white noise)
// -------------------------------------
clc, clear, close, mode(0);

// simulation
nd=500;                  // number of data
m=[2 -1 3]';             // parameters for
sdx=[.5 .1 .3            //   x-model
      0 .2 .1
      0  0 .8];
c=[4 -2 2];              // parameters for
k=5;                     //   y-model
sdy=.7;
for t=1:nd
  x(:,t)=m+sdx*rand(3,1,'n');           // data x
  y(t)=c*x(:,t)+k+sdy*rand(1,1,'n');    // data y
end

// initialization
// |  c  |k|
thE=[5 0 1 3]';          // initial parametrs
ka=1;                    // initial counter
V=eye(5,5);              
V(2:$,1)=thE;
V(1,2:$)=thE';
V=V*ka;                  // statistics (rank thE + 1)
tht=thE;  

// estimation
for t=1:nd
  Ps=[y(t) x(:,t)' 1]';  // extended reg. vector
  V=V+Ps*Ps';            // statistics
  ka=ka+1;               //   update
  Vy=V(1,1);
  Vyp=V(2:$,1);
  Vp=V(2:$,2:$);
  thE=inv(Vp)*Vyp;       // estimates
  tht=[tht thE];
end

// results
set(scf(),'position',[500 200 500 400])
plot(0:nd,tht)
title 'Evolution of the estimated parameters'
legend('c1','c2','c3','k');

disp('simulated parameters')
disp([c'; k])
disp('initial parameters')
disp(tht(:,1))
disp('estimated parameters')
disp(thE)
